package nfa

import java.io.File;
import java.io.IOException;
import java.util.Scanner;
import java.util.Vector;

/**
 * A simple scanner to help process NFA input files.
 * This class is modeled after {@link java.util.Scanner}.
 */
class NFAScanner(val file : File) {

	/** Just use an underlying Scanner to do all the work */
	val in = new Scanner(file);

	/**
	 * Return the next token, after converting it to an integer.  This
	 * method may throw an exception if the next token is not an integer.
	 */
	def nextInt() : Int = in.nextInt();

	/**
	 * Return true if the next token in the input stream can be
	 * interpreted as in integer value.
	 */
	def hasNextInt() : Boolean = in.hasNextInt();


	/**
	 * Return true if there is more input left.
	 */
	def hasNext() : Boolean = in.hasNext();

	/**
	 * Return the next line of text.
	 */
	def nextLine() : String = in.nextLine();

	/**
	 * Return true if the next token is an int list
	 * of the form <tt>(1,2,3)</tt>.
	 */
	def hasNextIntList() : Boolean = in.hasNext("\\(((([0-9]+,)+[0-9]+)|[0-9]+)?\\)");

	/**
	 * Read an int list of the form <tt>(1,2,3)</tt> and return
	 * it as a List of integers.
	 */
	def nextIntList() : List[Int] = {
		val raw = in.next("\\(((([0-9]+,)+[0-9]+)|[0-9]+)?\\)");
		val list = raw.substring(1, raw.length() - 1);
		if (list.length() > 0) { 
			val ns = list.split(",").toList;
			ns.map(Integer.parseInt(_));
		} else {
			Nil;
		}
	}
}
